@@ -1,4 +1,6 @@
-#  Copyright (c) 2002-2012 Zooko Wilcox-O'Hearn
+﻿# -*- coding: utf-8-with-signature-unix; fill-column: 77 -*-
+# -*- indent-tabs-mode: nil -*-
+
 #  This file is part of pyutil; see README.rst for licensing terms.
 
 """
@@ -21,17 +23,17 @@ the second, e.g.:
 >>> rep_bench(fib, 25, UNITS_PER_SECOND=1000)
 best: 1.968e+00,   3th-best: 1.987e+00, mean: 2.118e+00,   3th-worst: 2.175e+00, worst: 2.503e+00 (of     10)
 
-The output is reporting the number of milliseconds that executing the function
-took, divided by N, from ten different invocations of fib(). It reports the
-best, worst, M-th best, M-th worst, and mean, where "M" is the natural log of
-the number of invocations (in this case 10).
+The output is reporting the number of milliseconds that executing the
+function took, divided by N, from ten different invocations of
+fib(). It reports the best, worst, M-th best, M-th worst, and mean,
+where "M" is 1/4 of the number of invocations (in this case 10).
 
 2. Now run it with different values of N and look for patterns:
 
 >>> for N in 1, 5, 9, 13, 17, 21:
 ...  print "%2d" % N,
 ...  rep_bench(fib, N, UNITS_PER_SECOND=1000000)
-... 
+...
  1 best: 9.537e-01,   3th-best: 9.537e-01, mean: 1.121e+00,   3th-worst: 1.192e+00, worst: 2.146e+00 (of     10)
  5 best: 5.722e-01,   3th-best: 6.199e-01, mean: 7.200e-01,   3th-worst: 8.106e-01, worst: 8.106e-01 (of     10)
  9 best: 2.437e+00,   3th-best: 2.464e+00, mean: 2.530e+00,   3th-worst: 2.570e+00, worst: 2.676e+00 (of     10)
@@ -74,10 +76,12 @@ and the main function is to make them be methods of the same object, e.g.:
 
 4. Things to fix:
 
- a. I used to have it hooked up to use the "hotshot" profiler on the code being
- measured. I recently tried to change it to use the newer cProfile profiler
- instead, but I don't understand the interface to cProfiler so it just gives an
- exception if you pass profile=True. Please fix this and send me a patch.
+ a. I used to have it hooked up to use the "hotshot" profiler on the
+ code being measured. I recently tried to change it to use the newer
+ cProfile profiler instead, but I don't understand the interface to
+ cProfiler so it just gives an exception if you pass
+ profile=True. Please fix this and send me a patch. xxx change it to
+ statprof
 
  b. Wouldn't it be great if this script emitted results in a json format that
  was understood by a tool to make pretty interactive explorable graphs? The
@@ -85,8 +89,9 @@ and the main function is to make them be methods of the same object, e.g.:
  this work and send me a patch!
 """
 
-import operator, time
+import cProfile, operator, time
 from decimal import Decimal as D
+import thread
 
 #from pyutil import jsonutil as json
 
@@ -122,45 +127,62 @@ def mult(a, b):
     except TypeError:
         return to_decimal(a) * to_decimal(b)
 
-def rep_bench(func, n, initfunc=None, MAXREPS=10, MAXTIME=60.0, profile=False, profresultsfileobj=None, UNITS_PER_SECOND=1, quiet=False):
-    """
-    Will run the func up to MAXREPS times, but won't start a new run if MAXTIME
-    (wall-clock time) has already elapsed (unless MAXTIME is None).
+def _measure_empty_func_with_runtime(profile=False):
+    return  _bench_it_until_time(do_nothing, 2**32, runtime=0.03)
 
+def _measure_empty_func_with_reps(profile=False):
+    return  _bench_it_until_reps(do_nothing, 2**32, runreps=1000)
+
+def rep_bench(func, n, runtime=None, initfunc=None, runreps=None, runiters=10, profile=False, profresults="pyutil-benchutil.prof", UNITS_PER_SECOND=1, quiet=False):
+    """
     @param quiet Don't print anything--just return the results dict.
+    @param runtime How many seconds to run the inner loop (for measuring the time of the code-under-measurement). If None then do it runreps times regardless of how many seconds it takes.
+    @param runreps How many times to run the inner loop (for measuring the time of the code-under-measurement). If None then do it until runtime seconds have passed.
+    @param runiters How many times to run the outer loop (for generating statistics about the distribution of runtimes of the code-under-measurement).
     """
     assert isinstance(n, int), (n, type(n))
+    assert (runtime is None) != (runreps is None), "Choose either runtime mode or runreps mode. runtime: %s, runreps: %s" % (runtime, runreps,)
 
-    if profile and profresultsfileobj is None:
-        raise Exception('If you ask for profiling, you are required to pass a profresultsfileobject to write the results into.')
+    global worstemptymeasure
+    if runtime is not None:
+        (time_per_rep, reps) = _measure_empty_func_with_runtime(profile=profile)
+        if time_per_rep * MARGINOFERROR >= runtime:
+            raise BadMeasure("Apparently simply invoking an empty Python function can take as long as %0.10f seconds, and we were running reps for only about %0.10f seconds. So the measurement of the runtime of the code under benchmark is not reliable. Please pass a higher number for the 'runtime' argument to rep_bench().")
+    else:
+        (time_per_rep, reps) = _measure_empty_func_with_reps(profile=profile)
+        if (worstemptymeasure is None) or (time_per_rep > worstemptymeasure):
+            worstemptymeasure = time_per_rep
 
-    startwallclocktime = time.time()
-    tls = [] # elapsed time in seconds
-    bmes = []
-    while ((len(tls) < MAXREPS) or (MAXREPS is None)) and ((MAXTIME is None) or ((time.time() - startwallclocktime) < MAXTIME)):
+    tls = [] # (elapsed time per rep in seconds, numreps)
+    while len(tls) < runiters:
         if initfunc:
             initfunc(n)
-        try:
-            tl = bench_it(func, n, profile=profile, profresultsfileobj=profresultsfileobj)
-        except BadMeasure, bme:
-            bmes.append(bme)
+        if profile:
+            import statprof
+            statprof.start()
+            try:
+                tl, reps = bench_it(func, n, runtime=runtime, runreps=runreps)
+            finally:
+                statprof.stop()
         else:
-            tls.append(tl)
-    if len(tls) == 0:
-        raise Exception("Couldn't get any measurements within time limits or number-of-attempts limits. Maybe something is wrong with your clock? %s" % (bmes,))
-    sumtls = reduce(operator.__add__, tls)
+            tl, reps = bench_it(func, n, runtime=runtime, runreps=runreps)
+        tls.append((tl, reps))
+    sumtls = sum([tl for (tl, reps) in tls])
     mean = sumtls / len(tls)
     tls.sort()
-    worst = tls[-1]
-    best = tls[0]
-    _assert(best > worstemptymeasure*MARGINOFERROR, "%s(n=%s) took %0.10f seconds, but we cannot measure times much less than about %0.10f seconds. Try a more time-consuming variant (such as higher n)." % (func, n, best, worstemptymeasure*MARGINOFERROR,))
+    worst = tls[-1][0]
+    best = tls[0][0]
+
+    if best < (worstemptymeasure * MARGINOFERROR):
+        raise BadMeasure("Apparently simply invoking an empty Python function can take as long as %0.10f seconds, and we were running reps for only about %0.10f seconds. So the measurement of the runtime of the code under benchmark is not reliable. Please pass a higher number for the 'runtime' argument to rep_bench().")
+
     m = len(tls)/4
     if m > 0:
-        mthbest = tls[m-1]
-        mthworst = tls[-m]
+        mthbest = tls[m-1][0]
+        mthworst = tls[-m][0]
     else:
-        mthbest = tls[0]
-        mthworst = tls[-1]
+        mthbest = tls[0][0]
+        mthworst = tls[-1][0]
 
     # The +/-0 index is the best/worst, the +/-1 index is the 2nd-best/worst,
     # etc, so we use mp1 to name it.
@@ -178,9 +200,6 @@ def rep_bench(func, n, initfunc=None, MAXREPS=10, MAXTIME=60.0, profile=False, p
     if not quiet:
         print "best: %(best)#8.03e, %(mp1)3dth-best: %(mth-best)#8.03e, mean: %(mean)#8.03e, %(mp1)3dth-worst: %(mth-worst)#8.03e, worst: %(worst)#8.03e (of %(num)6d)" % res
 
-    if profile:
-        import statprof
-        statprof.display(profresultsfileobj)
     return res
 
 MARGINOFERROR = 10
@@ -190,48 +209,66 @@ worstemptymeasure = 0
 class BadMeasure(Exception):
     """ Either the clock wrapped (which happens with time.clock()) or
     it went backwards (which happens with time.time() on rare
-    occasions), (or the code being measured completed before a single
-    clock tick). """
-    def __init__(self, startt, stopt, clock):
-        self.startt = startt
-        self.stopt = stopt
-        self.clock = clock
+    occasions), or the code being measured completed too fast to
+    accurately measure. """
+    def __init__(self, msg):
+        self.msg = msg
 
     def __repr__(self):
-        return "<%s %s - %s (%s)>" % (self.__class__.__name__, self.startt, self.stopt, self.clock)
+        return "<%s %s>" % (self.__class__.__name__, self.msg)
+
+    def __str__(self):
+        return self.__repr__()
 
 def do_nothing(n):
     pass
 
-def bench_it(func, n, profile=False, profresultsfileobj=None):
-    if profile:
-        import statprof
-        st = clock()
-        statprof.start()
-        try:
+def _interrupt_me_later(delay):
+    time.sleep(delay)
+    thread.interrupt_main()
+
+def _bench_it_until_time(func, n, runtime=1.0):
+    reps = 0
+    st = clock()
+
+    # We run it once before starting the timer so that we'll have a
+    # resulting measurement, even if interrupted before we finish the
+    # first interruptible run.
+    func(n)
+    reps += 1
+    sto = clock()
+
+    try:
+        timer_thread =  thread.start_new_thread(_interrupt_me_later, (runtime,))
+        while True:
             func(n)
-        finally:
-            statprof.stop()
-            sto = clock()
-    else:
-        st = clock()
-        try:
-            func(n)
-        finally:
+            reps += 1
             sto = clock()
+    except KeyboardInterrupt:
+        timeelapsed = sto - st
+        if timeelapsed <= 0:
+            raise BadMeasure("timeelapsed: %s, reps: %s" % (timeelapsed, reps))
+        return (timeelapsed / reps, reps)
+
+def _bench_it_until_reps(func, n, runreps=1000):
+    st = clock()
+    for i in range(runreps):
+        func(n)
+    sto = clock()
     timeelapsed = sto - st
     if timeelapsed <= 0:
-        raise BadMeasure(timeelapsed)
-    global worstemptymeasure
-    emsta = clock()
-    do_nothing(2**32)
-    emstop = clock()
-    empty = emstop - emsta
-    if empty > worstemptymeasure:
-        worstemptymeasure = empty
-    return timeelapsed
+        raise BadMeasure("timeelapsed: %s, runreps: %s" % (timeelapsed, runreps))
+    return (timeelapsed / runreps, runreps)
 
-def bench(func, initfunc=None, TOPXP=21, MAXREPS=5, MAXTIME=60.0, profile=False, profresults="pyutil-benchutil.prof", outputjson=False, jsonresultsfname="pyutil-benchutil-results.json", UNITS_PER_SECOND=1):
+def bench_it(func, n, runtime=1.0, runreps=None):
+    assert (runtime is None) != (runreps is None), "Choose either runtime mode or runreps mode. runtime: %s, runreps: %s" % (runtime, runreps,)
+
+    if runtime is not None:
+        return _bench_it_until_time(func, n, runtime=runtime)
+    else:
+        return _bench_it_until_reps(func, n, runreps=runreps)
+
+def bench(func, initfunc=None, runtime=1.0, TOPXP=21, profile=False, profresults="pyutil-benchutil.prof", outputjson=False, jsonresultsfname="pyutil-benchutil-results.json", UNITS_PER_SECOND=1):
     BSIZES = []
     for i in range(TOPXP-6, TOPXP+1, 2):
         n = int(2 ** i)
@@ -244,7 +281,7 @@ def bench(func, initfunc=None, TOPXP=21, MAXREPS=5, MAXTIME=60.0, profile=False,
     res = {}
     for BSIZE in BSIZES:
         print "N: %7d," % BSIZE,
-        r = rep_bench(func, BSIZE, initfunc=initfunc, MAXREPS=MAXREPS, MAXTIME=MAXTIME, profile=profile, profresults=profresults, UNITS_PER_SECOND=UNITS_PER_SECOND)
+        r = rep_bench(func, BSIZE, initfunc=initfunc, runtime=runtime, profile=profile, profresults=profresults, UNITS_PER_SECOND=UNITS_PER_SECOND)
         res[BSIZE] = r
 
     #if outputjson:
