@@ -1,4 +1,7 @@
-#  Copyright (c) 2002-2009 Zooko "Zooko" Wilcox-O'Hearn
+﻿# -*- coding: utf-8-with-signature-unix; fill-column: 77 -*-
+# -*- indent-tabs-mode: nil -*-
+
+#  This file is part of pyutil; see README.rst for licensing terms.
 
 """
 This module offers three implementations of an LRUCache, which is a dict that
@@ -7,8 +10,7 @@ fixed maximum size.
 
 Warning: if -O optimizations are not turned on then LRUCache performs
 extensive self-analysis in every function call, which can take minutes
-and minutes for a large cache.  Turn on -O, or comment out assert
-self._assert_invariants()
+and minutes for a large cache.  Turn on -O, or comment out ``assert self._assert_invariants()``
 """
 
 import operator
@@ -540,7 +542,7 @@ class SmallLRUCache(dict):
             self._lru = dict.keys(self)
             assert self._assert_invariants()
             return self
-      
+
         for k in otherdict.iterkeys():
             if dict.has_key(self, k):
                 self._lru.remove(k)
@@ -594,7 +596,6 @@ class LinkedListLRUCache:
     Implementation of a length-limited O(1) LRU queue.
     Built for and used by PyPE:
     http://pype.sourceforge.net
-    original Copyright 2003 Josiah Carlson.
     useful methods and _assert_invariant added by Zooko for testing and benchmarking purposes
     """
     class Node:
