@@ -1,6 +1,9 @@
+﻿# -*- coding: utf-8-with-signature-unix; fill-column: 77 -*-
+# -*- indent-tabs-mode: nil -*-
 """
 Tools to mess with dicts.
 """
+import warnings
 
 import copy, operator
 from bisect import bisect_left, insort_left
@@ -11,6 +14,7 @@ def move(k, d1, d2, strict=False):
     """
     Move item with key k from d1 to d2.
     """
+    warnings.warn("deprecated", DeprecationWarning)
     if strict and not d1.has_key(k):
         raise KeyError, k
 
@@ -23,6 +27,7 @@ def subtract(d1, d2):
 
     @returns d1
     """
+    warnings.warn("deprecated", DeprecationWarning)
     if len(d1) > len(d2):
         for k in d2.keys():
             if d1.has_key(k):
@@ -35,12 +40,14 @@ def subtract(d1, d2):
 
 class DictOfSets(dict):
     def add(self, key, value):
+        warnings.warn("deprecated", DeprecationWarning)
         if key in self:
             self[key].add(value)
         else:
             self[key] = set([value])
 
     def discard(self, key, value):
+        warnings.warn("deprecated", DeprecationWarning)
         if not key in self:
             return
         self[key].discard(value)
@@ -49,6 +56,7 @@ class DictOfSets(dict):
 
 class UtilDict:
     def __init__(self, initialdata={}):
+        warnings.warn("deprecated", DeprecationWarning)
         self.d = {}
         self.update(initialdata)
 
@@ -171,8 +179,16 @@ class UtilDict:
 
 class NumDict:
     def __init__(self, initialdict={}):
+        warnings.warn("deprecated", DeprecationWarning)
         self.d = copy.deepcopy(initialdict)
 
+    def merge(self, otherdict):
+        """
+        Add all the values from otherdict into this dict.
+        """
+        for key, val in otherdict.iteritems():
+            self.add_num(key, val)
+
     def add_num(self, key, val, default=0):
         """
         If the key doesn't appear in self then it is created with value default
@@ -413,6 +429,7 @@ class ValueOrderedDict:
         return ValueOrderedDict.ValueIterator(self)
 
     def __init__(self, initialdata={}):
+        warnings.warn("deprecated", DeprecationWarning)
         self.d = {} # k: key, v: val
         self.l = [] # sorted list of tuples of (val, key,)
         self.update(initialdata)
