@@ -1,4 +1,6 @@
-#  Copyright (c) 2002-2010 Zooko Wilcox-O'Hearn
+﻿# -*- coding: utf-8-with-signature-unix; fill-column: 77 -*-
+# -*- indent-tabs-mode: nil -*-
+
 #  This file is part of pyutil; see README.rst for licensing terms.
 
 """
@@ -15,21 +17,31 @@ else:
     DBNoSuchFileError = bsddb.db.DBNoSuchFileError
 
 # read_file() and write_file() copied from Mark Seaborn's blog post.  Please
-# read it for rationale:
+# read it for complete rationale:
 # http://lackingrhoticity.blogspot.com/2009/12/readfile-and-writefile-in-python.html
+
 def read_file(filename, mode='rb'):
-  fh = open(filename, mode)
-  try:
-      return fh.read()
-  finally:
-      fh.close()
+    """ Read the contents of the file named filename and return it in
+    a string. This function closes the file handle before it returns
+    (even if the underlying Python implementation's garbage collector
+    doesn't). """
+    fh = open(filename, mode)
+    try:
+        return fh.read()
+    finally:
+        fh.close()
 
 def write_file(filename, data, mode='wb'):
-  fh = open(filename, mode)
-  try:
-      fh.write(data)
-  finally:
-      fh.close()
+    """ Write the string data into a file named filename. This
+    function closes the file handle (ensuring that the written data is
+    flushed from the perspective of the Python implementation) before
+    it returns (even if the underlying Python implementation's garbage
+    collector doesn't)."""
+    fh = open(filename, mode)
+    try:
+        fh.write(data)
+    finally:
+        fh.close()
 
 # For backwards-compatibility in case someone is using these names. We used to
 # have a superkludge in fileutil.py under these names.
