@@ -1,5 +1,6 @@
-#  Copyright (c) 2001 Autonomous Zone Industries
-#  Copyright (c) 2002-2009 Zooko Wilcox-O'Hearn
+﻿# -*- coding: utf-8-with-signature-unix; fill-column: 77 -*-
+# -*- indent-tabs-mode: nil -*-
+
 #  This file is part of pyutil; see README.rst for licensing terms.
 
 """
