@@ -1,4 +1,6 @@
-#  Copyright (c) 2002-2010 Zooko Wilcox-O'Hearn
+﻿# -*- coding: utf-8-with-signature-unix; fill-column: 77 -*-
+# -*- indent-tabs-mode: nil -*-
+
 #  This file is part of pyutil; see README.rst for licensing terms.
 
 # from the Python Standard Library
