@@ -1,4 +1,7 @@
-#  Copyright (c) 2002-2009 Zooko "Zooko" Wilcox-O'Hearn
+﻿# -*- coding: utf-8-with-signature-unix; fill-column: 77 -*-
+# -*- indent-tabs-mode: nil -*-
+
+#  This file is part of pyutil; see README.rst for licensing terms.
 
 """
 This module offers a Ordered Dict, which is a dict that preserves
@@ -337,7 +340,7 @@ class SmallOrderedDict(dict):
     """
     SmallOrderedDict is faster than OrderedDict for small sets.  How small?  That
     depends on your machine and which operations you use most often.  Use
-    performance profiling to determine whether the cache class that you are
+    performance profiling to determine whether the ordered dict class that you are
     using makes any difference to the performance of your program, and if it
     does, then run "quick_bench()" in test/test_cache.py to see which cache
     implementation is faster for the size of your datasets.
