@@ -1,9 +1,11 @@
-#!/usr/bin/env python
+﻿#!/usr/bin/env python
+# -*- coding: utf-8-with-signature-unix; fill-column: 77 -*-
+# -*- indent-tabs-mode: nil -*-
 
 import exceptions
 class UsageError(exceptions.Exception): pass
 
-import os, sys
+import sys
 import pkg_resources
 
 def main():
