@@ -1,5 +1,7 @@
-# Copyright (c) 2002-2010 Zooko Wilcox-O'Hearn
-#  This file is part of pyutil; see README.txt for licensing terms.
+﻿# -*- coding: utf-8-with-signature-unix; fill-column: 77 -*-
+# -*- indent-tabs-mode: nil -*-
+
+#  This file is part of pyutil; see README.rst for licensing terms.
 
 def commonprefix(l):
     cp = []
