@@ -1,5 +1,9 @@
-# Copyright (c) 2005-2009 Zooko Wilcox-O'Hearn
-#  This file is part of pyutil; see README.txt for licensing terms.
+﻿# -*- coding: utf-8-with-signature-unix; fill-column: 77 -*-
+# -*- indent-tabs-mode: nil -*-
+
+#  This file is part of pyutil; see README.rst for licensing terms.
+
+import warnings
 
 # from the Twisted library
 from twisted.internet import reactor
@@ -13,6 +17,8 @@ def callLater_weakly(delay, func, *args, **kwargs):
 
     Therefore, if this scheduled event is a bound method and it is the only thing keeping the object from being garbage collected, the object will be garbage collected and the event will be cancelled.
     """
+    warnings.warn("deprecated", DeprecationWarning)
+
     def cleanup(weakmeth, thedeadweakref):
         if weakmeth.callId.active():
             weakmeth.callId.cancel()
